@@ -12,7 +12,7 @@ use Config ();
 use Alien::Build::Log;
 
 # ABSTRACT: Build external dependencies for use in CPAN
-our $VERSION = '2.61_01'; # TRIAL VERSION
+our $VERSION = '2.62_01'; # TRIAL VERSION
 $VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
 
 
@@ -611,7 +611,8 @@ sub fetch
 
   my $secure = 0;
 
-  if(defined $url && $url =~ /^https:/ || $url !~ /:/)
+  $DB::single = 1;
+  if(defined $url && ($url =~ /^(https|file):/ || $url !~ /:/))
   {
     # considered secure when either https or a local file
     $secure = 1;
@@ -1392,7 +1393,7 @@ Alien::Build - Build external dependencies for use in CPAN
 
 =head1 VERSION
 
-version 2.61_01
+version 2.62_01
 
 =head1 SYNOPSIS
 
